@@ -7,7 +7,8 @@ import configparser
 
 
 def read(fname):
-    return open(os.path.join(os.path.dirname(__file__), fname), encoding="UTF-8").read()
+    return open(os.path.join(os.path.dirname(__file__), fname)).read()
+
 
 config = configparser.ConfigParser()
 config.readfp(open('tryton.cfg'))
@@ -16,7 +17,7 @@ info = dict(config.items('tryton'))
 for key in ('depends', 'extras_depend', 'xml'):
     if key in info:
         info[key] = info[key].strip().splitlines()
-major_version, minor_version = 5, 0
+major_version, minor_version = 6, 0
 
 requires = []
 
@@ -25,20 +26,23 @@ for dep in info.get('depends', []):
         requires.append('gnuhealth == %s' % (info.get('version')))
 
     elif dep.startswith('health_'):
-        health_package = dep.split('_',1)[1]
-        requires.append('gnuhealth_%s == %s' %
+        health_package = dep.split('_', 1)[1]
+        requires.append(
+            'gnuhealth_%s == %s' %
             (health_package, info.get('version')))
-    else: 
+    else:
         if not re.match(r'(ir|res|webdav)(\W|$)', dep):
-            requires.append('trytond_%s >= %s.%s, < %s.%s' %
+            requires.append(
+                'trytond_%s >= %s.%s, < %s.%s' %
                 (dep, major_version, minor_version, major_version,
                     minor_version + 1))
 
 
 requires = ['PyWebDAV3-GNUHealth >= 0.10.1', 'gnuhealth_webdav3_server']
-    
 
-setup(name='gnuhealth_caldav',
+
+setup(
+    name='gnuhealth_caldav',
     version=info.get('version', '0.0.1'),
     description='CalDAV package for GNU Health and Python3',
     long_description=read('README'),
@@ -47,13 +51,14 @@ setup(name='gnuhealth_caldav',
     url='https://www.gnuhealth.org',
     download_url='http://ftp.gnu.org/gnu/health/',
     keywords='GNUHealth calendar caldav',
-    package_dir={'trytond.modules.calendar': '.'},
+    package_dir={'trytond.modules.health_caldav': '.'},
     packages=[
-        'trytond.modules.calendar',
-        'trytond.modules.calendar.tests',
+        'trytond.modules.health_caldav',
+        'trytond.modules.health_caldav.tests',
         ],
     package_data={
-        'trytond.modules.calendar': (info.get('xml', [])
+        'trytond.modules.health_caldav': (
+            info.get('xml', [])
             + ['tryton.cfg', 'view/*.xml', 'locale/*.po']),
         },
     classifiers=[
@@ -74,12 +79,12 @@ setup(name='gnuhealth_caldav',
     license='GPL-3',
     install_requires=requires,
     extras_require={
-        'test': ['caldav'],
+        'test': ['health_caldav'],
         },
     zip_safe=False,
     entry_points="""
     [trytond.modules]
-    calendar = trytond.modules.calendar
+    health_caldav = trytond.modules.health_caldav
     """,
     test_suite='tests',
     test_loader='trytond.test_loader:Loader',
