@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -21,123 +20,39 @@
 #
 ##############################################################################
 from datetime import datetime
-from trytond.model import ModelView, ModelSingleton, ModelSQL, \
-    ValueMixin, fields, Unique
+from trytond.model import ModelView, ModelSQL, fields, Unique
 from trytond.transaction import Transaction
 from trytond.tools import grouped_slice, reduce_ids
-from sql import Literal, Table
+from sql import Literal
 from trytond.pool import Pool
 from trytond.pyson import Eval, Not, Bool, And, Equal, Or
-from trytond import backend
-from trytond.tools.multivalue import migrate_property
+from trytond.i18n import gettext
+from trytond.modules.health.core import get_health_professional, \
+    get_institution
 
 import pytz
 
+from .exceptions import (
+    NoAssociatedHealthProfessional,
+    DischargeReasonNeeded, DischargeBeforeAdmission,
+    BedIsNotAvailable, NeedTimeZone,
+    AdmissionMustBeToday, SpecialMealNeeds
+    )
 
 
-__all__ = ['GnuHealthSequences', 'GnuHealthSequenceSetup',
-    'DietTherapeutic','InpatientRegistration', 
+__all__ = [
+    'DietTherapeutic', 'InpatientRegistration',
     'BedTransfer', 'Appointment', 'PatientEvaluation', 'PatientData',
     'InpatientMedication', 'InpatientMedicationAdminTimes',
     'InpatientMedicationLog', 'InpatientDiet', 'InpatientMeal',
-    'InpatientMealOrder','InpatientMealOrderItem', 'ECG']
-
-
-sequences = ['inpatient_registration_sequence',
-            'inpatient_meal_order_sequence']
-
-
-class GnuHealthSequences(ModelSingleton, ModelSQL, ModelView, ValueMixin):
-    'GNU Health Sequences'
-    __name__ = 'gnuhealth.sequences'
-
-    inpatient_registration_sequence = fields.MultiValue(fields.Many2One(
-        'ir.sequence', 'Inpatient Sequence', required=True,
-        domain=[('code', '=', 'gnuhealth.inpatient.registration')]))
-
-    inpatient_meal_order_sequence = fields.MultiValue(fields.Many2One(
-        'ir.sequence', 'Inpatient Meal Sequence', required=True,
-        domain=[('code', '=', 'gnuhealth.inpatient.meal.order')]))
-
-
-    @classmethod
-    def multivalue_model(cls, field):
-        pool = Pool()
-
-        if field in sequences:
-            return pool.get('gnuhealth.sequence.setup')
-        return super(GnuHealthSequences, cls).multivalue_model(field)
-
-
-    @classmethod
-    def default_inpatient_registration_sequence(cls):
-        return cls.multivalue_model(
-            'inpatient_registration_sequence').default_inpatient_registration_sequence()
-
-
-    @classmethod
-    def default_inpatient_meal_order_sequence(cls):
-        return cls.multivalue_model(
-            'inpatient_meal_order_sequence').default_inpatient_meal_order_sequence()
-
-    
-# SEQUENCE SETUP
-class GnuHealthSequenceSetup(ModelSQL, ValueMixin):
-    'GNU Health Sequences Setup'
-    __name__ = 'gnuhealth.sequence.setup'
-
-    inpatient_registration_sequence = fields.Many2One('ir.sequence', 
-        'Inpatient Sequence', required=True,
-        domain=[('code', '=', 'gnuhealth.inpatient.registration')])
-
-
-    inpatient_meal_order_sequence = fields.Many2One('ir.sequence',
-        'Inpatient Meal Sequence', required=True,
-        domain=[('code', '=', 'gnuhealth.inpatient.meal.order')])
-
-  
-    @classmethod
-    def __register__(cls, module_name):
-        TableHandler = backend.get('TableHandler')
-        exist = TableHandler.table_exist(cls._table)
-
-        super(GnuHealthSequenceSetup, cls).__register__(module_name)
-
-        if not exist:
-            cls._migrate_property([], [], [])
-
-    @classmethod
-    def _migrate_property(cls, field_names, value_names, fields):
-        field_names.extend(sequences)
-        value_names.extend(sequences)
-        migrate_property(
-            'gnuhealth.sequences', field_names, cls, value_names,
-            fields=fields)
-
-    @classmethod
-    def default_inpatient_registration_sequence(cls):
-        pool = Pool()
-        ModelData = pool.get('ir.model.data')
-        return ModelData.get_id(
-            'health_inpatient', 'seq_gnuhealth_inpatient_registration')
-
-    @classmethod
-    def default_inpatient_meal_order_sequence(cls):
-        pool = Pool()
-        ModelData = pool.get('ir.model.data')
-        return ModelData.get_id(
-            'health_inpatient', 'seq_gnuhealth_inpatient_meal_order')
-    
-# END SEQUENCE SETUP , MIGRATION FROM FIELDS.PROPERTY
-
-
-
+    'InpatientMealOrder', 'InpatientMealOrderItem', 'ECG']
 
 # Therapeutic Diet types
 
+
 class DietTherapeutic (ModelSQL, ModelView):
     'Diet Therapy'
-    __name__="gnuhealth.diet.therapeutic"
+    __name__ = "gnuhealth.diet.therapeutic"
 
     name = fields.Char('Diet type', required=True, translate=True)
     code = fields.Char('Code', required=True)
@@ -149,7 +64,7 @@ class DietTherapeutic (ModelSQL, ModelView):
 
         t = cls.__table__()
         cls._sql_constraints = [
-            ('code_unique', Unique(t,t.code),
+            ('code_unique', Unique(t, t.code),
                 'The Diet code already exists'),
             ]
 
@@ -158,12 +73,14 @@ class InpatientRegistration(ModelSQL, ModelView):
     'Patient admission History'
     __name__ = 'gnuhealth.inpatient.registration'
 
-    STATES = {'readonly': Or(Eval('state') == 'done',
+    STATES = {'readonly': Or(
+        Eval('state') == 'done',
         Eval('state') == 'finished')}
-    
+
     name = fields.Char('Registration Code', readonly=True, select=True)
-    patient = fields.Many2One('gnuhealth.patient', 'Patient',
-     required=True, select=True, states = STATES)
+    patient = fields.Many2One(
+        'gnuhealth.patient', 'Patient',
+        required=True, select=True, states=STATES)
     admission_type = fields.Selection([
         (None, ''),
         ('routine', 'Routine'),
@@ -171,47 +88,59 @@ class InpatientRegistration(ModelSQL, ModelView):
         ('elective', 'Elective'),
         ('urgent', 'Urgent'),
         ('emergency', 'Emergency'),
-        ], 'Admission type', required=True, select=True, states = STATES)
-    hospitalization_date = fields.DateTime('Hospitalization date',
-        required=True, select=True, states = STATES)
-    discharge_date = fields.DateTime('Expected Discharge Date', required=True,
-        states = STATES)
-    attending_physician = fields.Many2One('gnuhealth.healthprofessional',
-        'Attending Physician',  states = STATES)
-    operating_physician = fields.Many2One('gnuhealth.healthprofessional',
-        'Operating Physician',  states = STATES)
-    admission_reason = fields.Many2One('gnuhealth.pathology',
-        'Reason for Admission', help="Reason for Admission",  states = STATES,
+        ], 'Admission type', required=True, select=True, states=STATES)
+    hospitalization_date = fields.DateTime(
+        'Hospitalization date',
+        required=True, select=True, states=STATES)
+    discharge_date = fields.DateTime(
+        'Expected Discharge Date', required=True,
+        states=STATES)
+    attending_physician = fields.Many2One(
+        'gnuhealth.healthprofessional',
+        'Attending Physician',  states=STATES)
+    operating_physician = fields.Many2One(
+        'gnuhealth.healthprofessional',
+        'Operating Physician',  states=STATES)
+    admission_reason = fields.Many2One(
+        'gnuhealth.pathology',
+        'Reason for Admission', help="Reason for Admission", states=STATES,
         select=True)
-    bed = fields.Many2One('gnuhealth.hospital.bed', 'Hospital Bed',
+    bed = fields.Many2One(
+        'gnuhealth.hospital.bed', 'Hospital Bed',
         states={
             'required': Not(Bool(Eval('name'))),
-            'readonly': Or(Eval('state') == 'done',
-                            Eval('state') == 'finished', 
-                            Bool(Eval('name')),
+            'readonly': Or(
+                Eval('state') == 'done',
+                Eval('state') == 'finished',
+                Bool(Eval('name')),
                         )
             },
         depends=['name'])
-    nursing_plan = fields.Text('Nursing Plan', states = STATES)
-    medications = fields.One2Many('gnuhealth.inpatient.medication', 'name',
-        'Medications', states = STATES)
-    therapeutic_diets = fields.One2Many('gnuhealth.inpatient.diet', 'name',
-        'Meals / Diet Program', states = STATES)
-        
-    nutrition_notes = fields.Text('Nutrition notes / directions', states = STATES)
-    discharge_plan = fields.Text('Discharge Plan', states = STATES)
-    info = fields.Text('Notes',states = STATES)
+    nursing_plan = fields.Text('Nursing Plan', states=STATES)
+    medications = fields.One2Many(
+        'gnuhealth.inpatient.medication', 'name',
+        'Medications', states=STATES)
+    therapeutic_diets = fields.One2Many(
+        'gnuhealth.inpatient.diet', 'name',
+        'Meals / Diet Program', states=STATES)
+
+    nutrition_notes = fields.Text(
+        'Nutrition notes / directions', states=STATES)
+    discharge_plan = fields.Text(
+        'Discharge Plan', states=STATES)
+    info = fields.Text('Notes', states=STATES)
     state = fields.Selection((
         (None, ''),
         ('free', 'free'),
         ('cancelled', 'cancelled'),
         ('confirmed', 'confirmed'),
         ('hospitalized', 'hospitalized'),
-        ('done','Discharged - needs cleaning'),
-        ('finished','Finished'),
+        ('done', 'Discharged - needs cleaning'),
+        ('finished', 'Finished'),
         ), 'Status', select=True, readonly=True)
-        
-    bed_transfers = fields.One2Many('gnuhealth.bed.transfer', 'name',
+
+    bed_transfers = fields.One2Many(
+        'gnuhealth.bed.transfer', 'name',
         'Transfer History', readonly=True)
 
     discharged_by = fields.Many2One(
@@ -220,32 +149,30 @@ class InpatientRegistration(ModelSQL, ModelView):
 
     discharge_reason = fields.Selection([
         (None, ''),
-        ('home','Home / Selfcare'),
-        ('transfer','Transferred to another institution'),
-        ('death','Death'),
-        ('against_advice','Left against medical advice')],
-        'Discharge Reason', 
-        states={'readonly': Not(Equal(Eval('state'), 'hospitalized')),},
+        ('home', 'Home / Selfcare'),
+        ('transfer', 'Transferred to another institution'),
+        ('death', 'Death'),
+        ('against_advice', 'Left against medical advice')],
+        'Discharge Reason',
+        states={'readonly': Not(Equal(Eval('state'), 'hospitalized'))},
         help="Reason for patient discharge")
 
-    discharge_dx = fields.Many2One('gnuhealth.pathology',
+    discharge_dx = fields.Many2One(
+        'gnuhealth.pathology',
         'Discharge Dx', help="Code for Discharge Diagnosis",
-        states={'readonly': Not(Equal(Eval('state'), 'hospitalized')),})
-  
-    institution = fields.Many2One('gnuhealth.institution', 'Institution',
+        states={'readonly': Not(Equal(Eval('state'), 'hospitalized'))})
+
+    institution = fields.Many2One(
+        'gnuhealth.institution', 'Institution',
         readonly=True)
 
     puid = fields.Function(
         fields.Char('PUID', help="Person Unique Identifier"),
         'get_patient_puid', searcher="search_patient_puid")
 
-
-
     @staticmethod
     def default_institution():
-        HealthInst = Pool().get('gnuhealth.institution')
-        institution = HealthInst.get_institution()
-        return institution
+        return get_institution()
 
     def get_patient_puid(self, name):
         return self.patient.name.ref
@@ -262,19 +189,14 @@ class InpatientRegistration(ModelSQL, ModelView):
         super(InpatientRegistration, cls).__setup__()
         t = cls.__table__()
         cls._sql_constraints = [
-            ('name_unique', Unique(t,t.name),
+            ('name_unique', Unique(t, t.name),
                 'The Registration code already exists'),
             ]
 
-        cls._error_messages.update({
-                'bed_is_not_available': 'Bed is not available',
-                'discharge_reason_needed': 'Admission and Discharge reasons \n'
-                'as well as Discharge Dx are needed',
-                'destination_bed_unavailable': 'Destination bed unavailable',
-                'need_timezone':'You need to set up the company timezone'})
         cls._buttons.update({
                 'confirmed': {
-                    'invisible': And(Not(Equal(Eval('state'), 'free')),
+                    'invisible': And(
+                        Not(Equal(Eval('state'), 'free')),
                         Not(Equal(Eval('state'), 'cancelled'))),
                     },
                 'cancel': {
@@ -291,7 +213,7 @@ class InpatientRegistration(ModelSQL, ModelView):
                     },
                 })
 
-    ## Method to check for availability and make the hospital bed reservation
+    # Method to check for availability and make the hospital bed reservation
     # Checks that there are not overlapping dates and status of the bed / room
     # is not confirmed, hospitalized or done but requiring cleaning ('done')
     @classmethod
@@ -301,22 +223,26 @@ class InpatientRegistration(ModelSQL, ModelView):
         Bed = Pool().get('gnuhealth.hospital.bed')
         cursor = Transaction().connection.cursor()
         bed_id = registration_id.bed.id
-        cursor.execute("SELECT COUNT(*) \
+        cursor.execute(
+            "SELECT COUNT(*) \
             FROM gnuhealth_inpatient_registration \
             WHERE (hospitalization_date::timestamp,discharge_date::timestamp) \
                 OVERLAPS (timestamp %s, timestamp %s) \
               AND (state = %s or state = %s or state = %s) \
               AND bed = CAST(%s AS INTEGER) ",
             (registration_id.hospitalization_date,
-            registration_id.discharge_date,
-            'confirmed', 'hospitalized', 'done', str(bed_id)))
+                registration_id.discharge_date,
+                'confirmed', 'hospitalized', 'done', str(bed_id)))
+
         res = cursor.fetchone()
         if (registration_id.discharge_date.date() <
-            registration_id.hospitalization_date.date()):
-            cls.raise_user_error("The Discharge date must later than the " \
-                "Admission")
+                registration_id.hospitalization_date.date()):
+            raise DischargeBeforeAdmission(
+                gettext('health_inpatient.msg_discharge_befor_admission'))
+
         if res[0] > 0:
-            cls.raise_user_error('bed_is_not_available')
+            raise BedIsNotAvailable(
+                gettext('health_inpatient.msg_bed_is_not_available'))
         else:
             cls.write(registrations, {'state': 'confirmed'})
             Bed.write([registration_id.bed], {'state': 'reserved'})
@@ -327,13 +253,14 @@ class InpatientRegistration(ModelSQL, ModelView):
         registration_id = registrations[0]
         Bed = Pool().get('gnuhealth.hospital.bed')
 
-        signing_hp = Pool().get('gnuhealth.healthprofessional').get_health_professional()
+        signing_hp = get_health_professional()
         if not signing_hp:
-            cls.raise_user_error(
-                "No health professional associated to this user !")
+            raise NoAssociatedHealthProfessional(
+                gettext('health_inpatient.'
+                        'msg_no_associated_health_professional'))
 
-        cls.write(registrations, {'state': 'done',
-            'discharged_by': signing_hp})
+        cls.write(registrations, {
+                    'state': 'done', 'discharged_by': signing_hp})
 
         Bed.write([registration_id.bed], {'state': 'to_clean'})
 
@@ -370,32 +297,39 @@ class InpatientRegistration(ModelSQL, ModelView):
             company = Company(company_id)
             if company.timezone:
                 timezone = pytz.timezone(company.timezone)
-                
+
                 dt = datetime.today()
-                dt_local = datetime.astimezone(dt.replace(tzinfo=pytz.utc),
-                 timezone)        
+                dt_local = datetime.astimezone(
+                    dt.replace(tzinfo=pytz.utc), timezone)
 
                 if (registration_id.hospitalization_date.date() !=
-                    dt_local.date()):
-                    cls.raise_user_error("The Admission date must be today")
+                        dt_local.date()):
+                    raise AdmissionMustBeToday(
+                        gettext('health_inpatient.'
+                                'msg_admission_must_be_today'))
                 else:
                     cls.write(registrations, {'state': 'hospitalized'})
                     Bed.write([registration_id.bed], {'state': 'occupied'})
 
             else:
-               cls.raise_user_error('need_timezone')
+                raise NeedTimeZone(
+                    gettext('health_inpatient.msg_need_timezone'))
+
+    @classmethod
+    def generate_code(cls, **pattern):
+        Config = Pool().get('gnuhealth.sequences')
+        config = Config(1)
+        sequence = config.get_multivalue(
+            'inpatient_registration_sequence', **pattern)
+        if sequence:
+            return sequence.get()
 
     @classmethod
     def create(cls, vlist):
-        Sequence = Pool().get('ir.sequence')
-        Config = Pool().get('gnuhealth.sequences')
-
         vlist = [x.copy() for x in vlist]
         for values in vlist:
             if not values.get('name'):
-                config = Config(1)
-                values['name'] = Sequence.get_id(
-                    config.inpatient_registration_sequence.id)
+                values['name'] = cls.generate_code()
         return super(InpatientRegistration, cls).create(vlist)
 
     @staticmethod
@@ -408,25 +342,22 @@ class InpatientRegistration(ModelSQL, ModelView):
         for registration in registrations:
             registration.check_discharge_context()
 
-
     def check_discharge_context(self):
         if ((not self.discharge_reason or not self.discharge_dx
             or not self.admission_reason)
-            and self.state == 'done'):
-                self.raise_user_error('discharge_reason_needed')
+                and self.state == 'done'):
+            raise DischargeReasonNeeded(
+                gettext('health_inpatient.msg_discharge_reason_needed'))
 
-    
     # Format Registration ID : Patient : Bed
     def get_rec_name(self, name):
         if self.patient:
-            return self.name + ':' + self.bed.rec_name + ':' \
-                + self.patient.rec_name 
-                
+            return f'{self.name}:{self.bed.rec_name}:{self.patient.rec_name}'
         else:
             return self.name
 
     # Allow searching by the hospitalization code, patient name
-    # or bed number 
+    # or bed number
 
     @classmethod
     def search_rec_name(cls, name, clause):
@@ -441,19 +372,16 @@ class InpatientRegistration(ModelSQL, ModelView):
         return [(cls._rec_name,) + tuple(clause[1:])]
 
 
-
-        
 class BedTransfer(ModelSQL, ModelView):
     'Bed transfers'
     __name__ = 'gnuhealth.bed.transfer'
 
-    name = fields.Many2One('gnuhealth.inpatient.registration',
+    name = fields.Many2One(
+        'gnuhealth.inpatient.registration',
         'Registration Code')
     transfer_date = fields.DateTime('Date')
-    bed_from = fields.Many2One('gnuhealth.hospital.bed', 'From',
-        )
-    bed_to = fields.Many2One('gnuhealth.hospital.bed', 'To',
-        )
+    bed_from = fields.Many2One('gnuhealth.hospital.bed', 'From')
+    bed_to = fields.Many2One('gnuhealth.hospital.bed', 'To')
     reason = fields.Char('Reason')
 
 
@@ -464,6 +392,7 @@ class Appointment(ModelSQL, ModelView):
         'gnuhealth.inpatient.registration', 'Inpatient Registration',
         help="Enter the patient hospitalization code")
 
+
 class PatientEvaluation(ModelSQL, ModelView):
     __name__ = 'gnuhealth.patient.evaluation'
 
@@ -471,6 +400,7 @@ class PatientEvaluation(ModelSQL, ModelView):
         'gnuhealth.inpatient.registration', 'IPC',
         help="Enter the patient hospitalization code")
 
+
 class ECG(ModelSQL, ModelView):
     __name__ = 'gnuhealth.patient.ecg'
 
@@ -483,8 +413,10 @@ class PatientData(ModelSQL, ModelView):
     'Inherit patient model and add the patient status to the patient.'
     __name__ = 'gnuhealth.patient'
 
-    patient_status = fields.Function(fields.Boolean('Hospitalized',
-        help="Show the hospitalization status of the patient"),
+    patient_status = fields.Function(
+        fields.Boolean(
+            'Hospitalized',
+            help="Show the hospitalization status of the patient"),
         getter='get_patient_status', searcher='search_patient_status')
 
     @classmethod
@@ -503,7 +435,8 @@ class PatientData(ModelSQL, ModelView):
             clause_ids = reduce_ids(registration.id, sub_ids)
 
             # Hospitalized patient ids
-            query = registration.select(registration.patient, Literal(True),
+            query = registration.select(
+                registration.patient, Literal(True),
                 where=(registration.state == 'hospitalized') & clause_ids,
                 group_by=registration.patient)
 
@@ -527,8 +460,8 @@ class PatientData(ModelSQL, ModelView):
             raise ValueError('Wrong value: %s' % value)
 
         # Find hospitalized patient ids
-        j = pat.join(table, condition = pat.id == table.patient)
-        s = j.select(pat.id, where = table.state == 'hospitalized')
+        j = pat.join(table, condition=pat.id == table.patient)
+        s = j.select(pat.id, where=table.state == 'hospitalized')
 
         # Choose domain operator
         if (operator == '=' and value) or (operator == '!=' and not value):
@@ -538,37 +471,51 @@ class PatientData(ModelSQL, ModelView):
 
         return [('id', d, s)]
 
+
 class InpatientMedication (ModelSQL, ModelView):
     'Inpatient Medication'
     __name__ = 'gnuhealth.inpatient.medication'
 
-    name = fields.Many2One('gnuhealth.inpatient.registration',
+    name = fields.Many2One(
+        'gnuhealth.inpatient.registration',
         'Registration Code')
-    medicament = fields.Many2One('gnuhealth.medicament', 'Medicament',
+    medicament = fields.Many2One(
+        'gnuhealth.medicament', 'Medicament',
         required=True, help='Prescribed Medicament')
-    indication = fields.Many2One('gnuhealth.pathology', 'Indication',
+    indication = fields.Many2One(
+        'gnuhealth.pathology', 'Indication',
         help='Choose a disease for this medicament from the disease list. It'
         ' can be an existing disease of the patient or a prophylactic.')
-    start_treatment = fields.DateTime('Start',
+    start_treatment = fields.DateTime(
+        'Start',
         help='Date of start of Treatment', required=True)
     end_treatment = fields.DateTime('End', help='Date of start of Treatment')
-    dose = fields.Float('Dose',
+    dose = fields.Float(
+        'Dose',
         help='Amount of medication (eg, 250 mg) per dose', required=True)
-    dose_unit = fields.Many2One('gnuhealth.dose.unit', 'dose unit',
+    dose_unit = fields.Many2One(
+        'gnuhealth.dose.unit', 'dose unit',
         required=True, help='Unit of measure for the medication to be taken')
-    route = fields.Many2One('gnuhealth.drug.route', 'Administration Route',
+    route = fields.Many2One(
+        'gnuhealth.drug.route', 'Administration Route',
         required=True, help='Drug administration route code.')
-    form = fields.Many2One('gnuhealth.drug.form', 'Form', required=True,
+    form = fields.Many2One(
+        'gnuhealth.drug.form', 'Form', required=True,
         help='Drug form, such as tablet or gel')
-    qty = fields.Integer('x', required=True,
+    qty = fields.Integer(
+        'x', required=True,
         help='Quantity of units (eg, 2 capsules) of the medicament')
-    common_dosage = fields.Many2One('gnuhealth.medication.dosage', 'Frequency',
+    common_dosage = fields.Many2One(
+        'gnuhealth.medication.dosage', 'Frequency',
         help='Common / standard dosage frequency for this medicament')
-    admin_times = fields.One2Many('gnuhealth.inpatient.medication.admin_time',
+    admin_times = fields.One2Many(
+        'gnuhealth.inpatient.medication.admin_time',
         'name', "Admin times")
-    log_history = fields.One2Many('gnuhealth.inpatient.medication.log', 'name',
+    log_history = fields.One2Many(
+        'gnuhealth.inpatient.medication.log', 'name',
         "Log History")
-    frequency = fields.Integer('Frequency',
+    frequency = fields.Integer(
+        'Frequency',
         help='Time in between doses the patient must wait (ie, for 1 pill'
         ' each 8 hours, put here 8 and select \"hours\" in the unit field')
     frequency_unit = fields.Selection([
@@ -580,20 +527,23 @@ class InpatientMedication (ModelSQL, ModelView):
         ('weeks', 'weeks'),
         ('wr', 'when required'),
         ], 'unit', select=True, sort=False)
-    frequency_prn = fields.Boolean('PRN',
-        help='Use it as needed, pro re nata')
-    is_active = fields.Boolean('Active',
+    frequency_prn = fields.Boolean('PRN', help='Use it as needed, pro re nata')
+
+    is_active = fields.Boolean(
+        'Active',
         help='Check if the patient is currently taking the medication')
     discontinued = fields.Boolean('Discontinued')
     course_completed = fields.Boolean('Course Completed')
-    discontinued_reason = fields.Char('Reason for discontinuation',
+    discontinued_reason = fields.Char(
+        'Reason for discontinuation',
         states={
             'invisible': Not(Bool(Eval('discontinued'))),
             'required': Bool(Eval('discontinued')),
             },
         depends=['discontinued'],
         help='Short description for discontinuing the treatment')
-    adverse_reaction = fields.Text('Adverse Reactions',
+    adverse_reaction = fields.Text(
+        'Adverse Reactions',
         help='Side effects or adverse reactions that the patient experienced')
 
     @fields.depends('discontinued', 'course_completed')
@@ -618,41 +568,40 @@ class InpatientMedication (ModelSQL, ModelView):
 
 class InpatientMedicationAdminTimes (ModelSQL, ModelView):
     'Inpatient Medication Admin Times'
-    __name__="gnuhealth.inpatient.medication.admin_time"
+    __name__ = "gnuhealth.inpatient.medication.admin_time"
 
     name = fields.Many2One('gnuhealth.inpatient.medication', 'Medication')
     admin_time = fields.Time("Time")
-    dose = fields.Float('Dose',
+    dose = fields.Float(
+        'Dose',
         help='Amount of medication (eg, 250 mg) per dose')
-    dose_unit = fields.Many2One('gnuhealth.dose.unit', 'dose unit',
+    dose_unit = fields.Many2One(
+        'gnuhealth.dose.unit', 'dose unit',
         help='Unit of measure for the medication to be taken')
-    remarks = fields.Text('Remarks',
+    remarks = fields.Text(
+        'Remarks',
         help='specific remarks for this dose')
 
 
 class InpatientMedicationLog (ModelSQL, ModelView):
     'Inpatient Medication Log History'
-    __name__="gnuhealth.inpatient.medication.log"
+    __name__ = "gnuhealth.inpatient.medication.log"
 
     name = fields.Many2One('gnuhealth.inpatient.medication', 'Medication')
     admin_time = fields.DateTime("Date", readonly=True)
-    health_professional = fields.Many2One('gnuhealth.healthprofessional',
+    health_professional = fields.Many2One(
+        'gnuhealth.healthprofessional',
         'Health Professional', readonly=True)
-    dose = fields.Float('Dose',
+    dose = fields.Float(
+        'Dose',
         help='Amount of medication (eg, 250 mg) per dose')
-    dose_unit = fields.Many2One('gnuhealth.dose.unit', 'dose unit',
+    dose_unit = fields.Many2One(
+        'gnuhealth.dose.unit', 'dose unit',
         help='Unit of measure for the medication to be taken')
-    remarks = fields.Text('Remarks',
+    remarks = fields.Text(
+        'Remarks',
         help='specific remarks for this dose')
 
-    @classmethod
-    def __setup__(cls):
-        super(InpatientMedicationLog, cls).__setup__()
-        cls._error_messages.update({
-            'health_professional_warning':
-                    'No health professional associated to this user',
-        })
-
     @classmethod
     def validate(cls, records):
         super(InpatientMedicationLog, cls).validate(records)
@@ -661,12 +610,12 @@ class InpatientMedicationLog (ModelSQL, ModelView):
 
     def check_health_professional(self):
         if not self.health_professional:
-            self.raise_user_error('health_professional_warning')
+            raise NoAssociatedHealthProfessional(
+                gettext('health.msg_no_associated_health_professional'))
 
     @staticmethod
     def default_health_professional():
-        pool = Pool()
-        return pool.get('gnuhealth.healthprofessional').get_health_professional()
+        return get_health_professional()
 
     @staticmethod
     def default_admin_time():
@@ -675,60 +624,64 @@ class InpatientMedicationLog (ModelSQL, ModelView):
 
 class InpatientDiet (ModelSQL, ModelView):
     'Inpatient Diet'
-    __name__="gnuhealth.inpatient.diet"
+    __name__ = "gnuhealth.inpatient.diet"
 
-    name = fields.Many2One('gnuhealth.inpatient.registration',
+    name = fields.Many2One(
+        'gnuhealth.inpatient.registration',
         'Registration Code')
     diet = fields.Many2One('gnuhealth.diet.therapeutic', 'Diet', required=True)
-    remarks = fields.Text('Remarks / Directions',
+    remarks = fields.Text(
+        'Remarks / Directions',
         help='specific remarks for this diet / patient')
 
+
 class InpatientMeal (ModelSQL, ModelView):
     'Inpatient Meal'
-    __name__="gnuhealth.inpatient.meal"
+    __name__ = "gnuhealth.inpatient.meal"
 
     name = fields.Many2One(
         'product.product', 'Food', required=True,
         help='Food')
 
-    diet_therapeutic = fields.Many2One('gnuhealth.diet.therapeutic',
+    diet_therapeutic = fields.Many2One(
+        'gnuhealth.diet.therapeutic',
         'Diet')
 
-    diet_belief = fields.Many2One('gnuhealth.diet.belief',
-        'Belief')
+    diet_belief = fields.Many2One('gnuhealth.diet.belief', 'Belief')
 
-    diet_vegetarian = fields.Many2One('gnuhealth.vegetarian_types',
+    diet_vegetarian = fields.Many2One(
+        'gnuhealth.vegetarian_types',
         'Vegetarian')
 
     institution = fields.Many2One('gnuhealth.institution', 'Institution')
 
     @staticmethod
     def default_institution():
-        HealthInst = Pool().get('gnuhealth.institution')
-        institution = HealthInst.get_institution()
-        return institution
+        return get_institution()
 
     def get_rec_name(self, name):
         if self.name:
             return self.name.name
 
+
 class InpatientMealOrderItem (ModelSQL, ModelView):
     'Inpatient Meal Item'
-    __name__="gnuhealth.inpatient.meal.order.item"
+    __name__ = "gnuhealth.inpatient.meal.order.item"
 
-    name = fields.Many2One('gnuhealth.inpatient.meal.order',
+    name = fields.Many2One(
+        'gnuhealth.inpatient.meal.order',
         'Meal Order')
 
     meal = fields.Many2One('gnuhealth.inpatient.meal', 'Meal')
-
     remarks = fields.Char('Remarks')
 
 
 class InpatientMealOrder (ModelSQL, ModelView):
     'Inpatient Meal Order'
-    __name__="gnuhealth.inpatient.meal.order"
+    __name__ = "gnuhealth.inpatient.meal.order"
 
-    name = fields.Many2One('gnuhealth.inpatient.registration',
+    name = fields.Many2One(
+        'gnuhealth.inpatient.registration',
         'Registration Code', domain=[('state', '=', 'hospitalized')],
         required=True)
 
@@ -741,25 +694,28 @@ class InpatientMealOrder (ModelSQL, ModelView):
         ('special', 'Special order'),
         ), 'Meal time', required=True, sort=False)
 
-    meal_item = fields.One2Many('gnuhealth.inpatient.meal.order.item', 'name',
+    meal_item = fields.One2Many(
+        'gnuhealth.inpatient.meal.order.item', 'name',
         'Items')
 
     meal_order = fields.Char('Order', readonly=True)
 
-    health_professional = fields.Many2One('gnuhealth.healthprofessional',
+    health_professional = fields.Many2One(
+        'gnuhealth.healthprofessional',
         'Health Professional')
 
     remarks = fields.Text('Remarks')
 
-    meal_warning = fields.Boolean('Warning',
+    meal_warning = fields.Boolean(
+        'Warning',
         help="The patient has special needs on meals")
 
-    meal_warning_ack = fields.Boolean('Ack',
+    meal_warning_ack = fields.Boolean(
+        'Ack',
         help="Check if you have verified the warnings on the"
         " patient meal items")
 
-    order_date = fields.DateTime('Date',
-        help='Order date', required=True)
+    order_date = fields.DateTime('Date', help='Order date', required=True)
 
     state = fields.Selection((
         (None, ''),
@@ -767,7 +723,7 @@ class InpatientMealOrder (ModelSQL, ModelView):
         ('cancelled', 'Cancelled'),
         ('ordered', 'Ordered'),
         ('processing', 'Processing'),
-        ('done','Done'),
+        ('done', 'Done'),
         ), 'Status', readonly=True)
 
     @staticmethod
@@ -780,20 +736,23 @@ class InpatientMealOrder (ModelSQL, ModelView):
 
     @staticmethod
     def default_health_professional():
-        pool = Pool()
-        return pool.get('gnuhealth.healthprofessional').get_health_professional()
+        return get_health_professional()
+
+    @classmethod
+    def generate_code(cls, **pattern):
+        Config = Pool().get('gnuhealth.sequences')
+        config = Config(1)
+        sequence = config.get_multivalue(
+            'inpatient_meal_order_sequence', **pattern)
+        if sequence:
+            return sequence.get()
 
     @classmethod
     def create(cls, vlist):
-        Sequence = Pool().get('ir.sequence')
-        Config = Pool().get('gnuhealth.sequences')
-
         vlist = [x.copy() for x in vlist]
         for values in vlist:
             if not values.get('meal_order'):
-                config = Config(1)
-                values['meal_order'] = Sequence.get_id(
-                    config.inpatient_meal_order_sequence.id)
+                values['meal_order'] = cls.generate_code()
         return super(InpatientMealOrder, cls).create(vlist)
 
     @classmethod
@@ -802,27 +761,27 @@ class InpatientMealOrder (ModelSQL, ModelView):
         for meal_order in meal_orders:
             meal_order.check_meal_order_warning()
             meal_order.check_health_professional()
-            
+
     def check_meal_order_warning(self):
         if not self.meal_warning_ack and self.meal_warning:
-            self.raise_user_error('meal_order_warning')
+            raise SpecialMealNeeds(
+                gettext('health_inpatient.msg_special_meal_needs'))
 
     def check_health_professional(self):
         if not self.health_professional:
-            self.raise_user_error('health_professional_warning')
-
+            raise NoAssociatedHealthProfessional(
+                gettext('health.msg_no_associated_health_professional'))
 
     @fields.depends('name')
     def on_change_name(self):
         if self.name:
-            # Trigger the warning if the patient 
+            # Trigger the warning if the patient
             # has special needs on meals (religion / philosophy )
-            if (self.name.patient.vegetarian_type or 
-                self.name.patient.diet_belief):
+            if (self.name.patient.vegetarian_type or
+                    self.name.patient.diet_belief):
                 self.meal_warning = True
                 self.meal_warning_ack = False
 
-
     @classmethod
     def __setup__(cls):
         super(InpatientMealOrder, cls).__setup__()
@@ -831,31 +790,21 @@ class InpatientMealOrder (ModelSQL, ModelView):
             })
 
         cls._buttons.update({
-            'generate': {'invisible': Or(Equal(Eval('state'), 'ordered'),
-                    Equal(Eval('state'), 'done'))},
+            'generate': {
+                'invisible': Or(Equal(Eval('state'), 'ordered'),
+                                Equal(Eval('state'), 'done'))},
             })
 
         cls._buttons.update({
             'done': {'invisible': Not(Equal(Eval('state'), 'ordered'))}
             })
 
-        cls._error_messages.update({
-            'meal_order_warning':
-            '===== MEAL WARNING ! =====\n\n\n'
-            'This patient has special meal needs \n\n'
-            'Check and acknowledge that\n'
-            'the meal items in this order are correct \n\n',
-            'health_professional_warning':
-            'No health professional associated to this user',
-            })
-
         t = cls.__table__()
         cls._sql_constraints = [
-            ('meal_order_uniq', Unique(t,t.meal_order),
+            ('meal_order_uniq', Unique(t, t.meal_order),
                 'The Meal Order code already exists'),
             ]
 
-
     @classmethod
     @ModelView.button
     def generate(cls, mealorders):
