@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #
 #
@@ -23,11 +22,11 @@
 ##############################################################################
 import datetime
 import decimal
-from trytond.model import ModelView
-from trytond.wizard import Wizard, StateTransition, StateView, Button
+from trytond.wizard import Wizard
 from trytond.transaction import Transaction
 from trytond.pool import Pool
-
+from trytond.i18n import gettext
+from ..exceptions import (ServiceInvoiced, NoInvoiceAddress, NoPaymentTerm)
 
 __all__ = ['CreateServiceInvoice']
 
@@ -35,18 +34,17 @@ __all__ = ['CreateServiceInvoice']
 class CreateServiceInvoice(Wizard):
     __name__ = 'gnuhealth.service.invoice.create'
 
-#  
 #  name: CreateServiceInvoice.discount_policy
 #  @param : Insurance, service line product
 #  @return : Policy applied to that service line
-#  
+
     def discount_policy(self, insurance, product):
         # Check that there is a plan associated to the insurance
         if insurance.plan_id:
             # Traverse the product policies within the plan
             # In terms of applying discount, category and product are
             # mutually exclusive.
-            
+
             discount = {}
             if insurance.plan_id.product_policy:
                 for policy in insurance.plan_id.product_policy:
@@ -56,17 +54,17 @@ class CreateServiceInvoice(Wizard):
                             discount['value'] = policy.discount
                             discount['type'] = 'pct'
                             return discount
-                    
+
                 for policy in insurance.plan_id.product_policy:
                     # Then, if there's no product, check for the category
                     if (policy.product_category in product.categories):
                         if policy.discount:
                             discount['value'] = policy.discount
-                            discount['type'] = 'pct' 
+                            discount['type'] = 'pct'
                             return discount
 
             return discount
-    
+
     def transition_create_service_invoice(self):
         pool = Pool()
         HealthService = pool.get('gnuhealth.health_service')
@@ -80,10 +78,12 @@ class CreateServiceInvoice(Wizard):
             'active_ids'))
         invoices = []
 
-        #Invoice Header
+        # Invoice Header
         for service in services:
             if service.state == 'invoiced':
-                self.raise_user_error('duplicate_invoice')
+                raise ServiceInvoiced(
+                    gettext('health_insurance.msg_service_invoiced')
+                    )
             if service.invoice_to:
                 party = service.invoice_to
             else:
@@ -120,16 +120,21 @@ class CreateServiceInvoice(Wizard):
 
             party_address = Party.address_get(party, type='invoice')
             if not party_address:
-                self.raise_user_error('no_invoice_address')
+                raise NoInvoiceAddress(
+                    gettext('health_insurance.msg_no_invoice_address')
+                    )
+
             invoice_data['invoice_address'] = party_address.id
             invoice_data['reference'] = service.name
 
             if not party.customer_payment_term:
-                self.raise_user_error('no_payment_term')
+                raise NoPaymentTerm(
+                    gettext('health_insurance.msg_no_payment_term')
+                    )
 
             invoice_data['payment_term'] = party.customer_payment_term.id
 
-            #Invoice Lines
+            # Invoice Lines
             seq = 0
             invoice_lines = []
             for line in service.service_line:
@@ -138,37 +143,39 @@ class CreateServiceInvoice(Wizard):
 
                 if sale_price_list:
                     with Transaction().set_context(ctx):
-                        unit_price = sale_price_list.compute(party,
+                        unit_price = sale_price_list.compute(
+                            party,
                             line.product, line.product.list_price,
                             line.qty, line.product.default_uom)
                 else:
                     unit_price = line.product.list_price
-                    
+
                 if line.to_invoice:
                     taxes = []
                     desc = line.desc
-                    
-                    #Include taxes related to the product on the invoice line
+
+                    # Include taxes related to the product on the invoice line
                     for product_tax_line in line.product.customer_taxes_used:
                         taxes.append(product_tax_line.id)
 
                     # Check the Insurance policy for this service
                     if service.insurance_plan:
-                        discount = \
-                            self.discount_policy(service.insurance_plan, \
-                                line.product)
+                        discount = self.discount_policy(
+                            service.insurance_plan,
+                            line.product)
 
                         if discount:
                             if 'value' in list(discount.keys()):
                                 if discount['value']:
                                     if (discount['type'] == 'pct'):
-                                        unit_price *= (1 - 
-                                            decimal.Decimal(discount['value'])/100)
+                                        unit_price *= (
+                                            1 - decimal.Decimal(
+                                                discount['value'])/100)
 
-                                        # Add a remark on the description discount
+                                        # Add remark on description discount
                                         str_disc = str(discount['value']) + '%'
                                         desc = line.desc + " (Discnt " + \
-                                          str (str_disc) + ")"
+                                            str(str_disc) + ")"
 
                     invoice_lines.append(('create', [{
                             'origin': str(line),
@@ -179,7 +186,7 @@ class CreateServiceInvoice(Wizard):
                             'unit': line.product.default_uom.id,
                             'unit_price': unit_price,
                             'sequence': seq,
-                            'taxes': [('add',taxes)],
+                            'taxes': [('add', taxes)],
                         }]))
                 invoice_data['lines'] = invoice_lines
 
