@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -22,11 +22,12 @@
 ##############################################################################
 
 from trytond.pool import Pool
-from .health_ntd_dengue import *
+from . import health_ntd_dengue
+from . import sequences
 
 def register():
     Pool.register(
-        DengueDUSurvey,
-        GnuHealthSequences,
-        GnuHealthSequenceSetup,
+        health_ntd_dengue.DengueDUSurvey,
+        sequences.GnuHealthSequences,
+        sequences.DengueDUSurveySequence,
         module='health_ntd_dengue', type_='model')
